# shell_executor/executor.py

import os
import subprocess

class ShellExecutor:
    def __init__(self, sudo=False, verbose=True):
        """
        Inicializa o executador de shell.

        :param sudo: Se True, executa comandos com sudo quando necessário.
        :param verbose: Se True, imprime os comandos e saídas.
        """
        self.sudo = sudo
        self.verbose = verbose

    def _print(self, message):
        if self.verbose:
            print(message)

    def shell(self, command, cwd=None):
        """
        Executa um comando de shell.

        :param command: Comando a ser executado.
        :param cwd: Diretório de trabalho onde o comando será executado.
        :return: Saída do comando.
        """
        if self.sudo and os.geteuid() != 0:
            self._print('  * Sudo Active')
            if 'cd' not in command and 'echo' not in command:
                command = f"sudo {command}"

        if cwd:
            self._print(f'  \033[1m* Cwd:\033[0m {cwd}')
        self._print(f'  \033[1m* Command:\033[0m {command}')

        env_vars = os.environ.copy()

        process = subprocess.Popen(
            command, shell=True,
            stdout=subprocess.PIPE, stderr=subprocess.STDOUT,
            cwd=cwd, env=env_vars, universal_newlines=True
        )

        output = ""
        for line in process.stdout:
            self._print(line.strip())
            output += line

        process.wait()
        if process.returncode != 0:
            self._print(f"Error, Executing command: {command}")
            exit(process.returncode)

        return output

